@@ -4,36 +4,27 @@
 #include "action/Action.hpp"
 #include "mesh/SharedPointer.hpp"
 
-namespace precice {
-namespace action {
+namespace precice::action {
 
 /// Action that records invocations for testing purposes
 class RecorderAction : public Action {
 public:
   /**
-	 * @brief Constructor
-	 * 
-	 * @param[in] timing When to apply the action.
-	 * @param[in] mesh the target mesh.
-	 * 
-	 */
+   * @brief Constructor
+   *
+   * @param[in] timing When to apply the action.
+   * @param[in] mesh the target mesh.
+   *
+   */
   RecorderAction(
       Timing               timing,
       const mesh::PtrMesh &mesh);
 
   /// Records the invocation and appends it to the records
-  void performAction(
-      double time,
-      double timeStepSize,
-      double computedTimeWindowPart,
-      double timeWindowSize) override;
+  void performAction() final override;
 
   struct Record {
     Timing timing;
-    double time;
-    double timeStepSize;
-    double computedTimeWindowPart;
-    double timeWindowSize;
   };
 
   /// resets the saved records.
@@ -42,5 +33,4 @@ public:
   static std::vector<Record> records;
 };
 
-} // namespace action
-} // namespace precice
+} // namespace precice::action
