@@ -5,8 +5,7 @@
 #include "mapping/Mapping.hpp"
 #include "mapping/Polation.hpp"
 
-namespace precice {
-namespace mapping {
+namespace precice::mapping {
 
 /**
  * @brief Base class for interpolation based mappings, where mapping is done using a geometry-based linear combination of input values.
@@ -27,13 +26,12 @@ private:
 
 protected:
   /// @copydoc Mapping::mapConservative
-  void mapConservative(DataID inputDataID, DataID outputDataID) override;
+  void mapConservative(const time::Sample &inData, Eigen::VectorXd &outData) override;
 
   /// @copydoc Mapping::mapConsistent
-  void mapConsistent(DataID inputDataID, DataID outputDataID) override;
+  void mapConsistent(const time::Sample &inData, Eigen::VectorXd &outData) override;
 
   std::vector<Polation> _interpolations;
 };
 
-} // namespace mapping
-} // namespace precice
+} // namespace precice::mapping
