@@ -1,12 +1,11 @@
 #include "partition/ReceivedPartition.hpp"
 
-namespace precice {
-namespace partition {
+namespace precice::partition {
 
 /*
  * @brief A fixture that is used to access private functions of the receivedPartition class.
  *
- * The fixture can be used to call private functions for individual testing. 
+ * The fixture can be used to call private functions for individual testing.
  */
 struct ReceivedPartitionFixture {
   static void createOwnerInformation(ReceivedPartition &part)
@@ -23,5 +22,4 @@ struct ReceivedPartitionFixture {
   }
 };
 
-} // namespace partition
-} // namespace precice
+} // namespace precice::partition
