@@ -2,12 +2,11 @@
 
 #include "cplscheme/SerialCouplingScheme.hpp"
 
-namespace precice {
-namespace testing {
+namespace precice::testing {
 /*
  * @brief A fixture that is used to access private functions of the SerialCouplingScheme class.
  *
- * The fixture can be used to call private functions for individual testing. 
+ * The fixture can be used to call private functions for individual testing.
  */
 struct SerialCouplingSchemeFixture {
   static bool isImplicitCouplingScheme(cplscheme::SerialCouplingScheme &cplscheme);
@@ -20,12 +19,9 @@ struct SerialCouplingSchemeFixture {
 
   static void storeIteration(cplscheme::SerialCouplingScheme &cplscheme);
 
-  static void initializeStorages(cplscheme::SerialCouplingScheme &cplscheme);
-
-  static void storeExtrapolationData(cplscheme::SerialCouplingScheme &cplscheme);
+  static void initializeAcceleration(cplscheme::SerialCouplingScheme &cplscheme);
 
   static void moveToNextWindow(cplscheme::SerialCouplingScheme &cplscheme);
 };
 
-} // namespace testing
-} // namespace precice
+} // namespace precice::testing
