@@ -3,23 +3,21 @@
 #include "helpers.hpp"
 #include "testing/Testing.hpp"
 
-#include "precice/SolverInterface.hpp"
+#include "precice/precice.hpp"
 
 void testConvergenceMeasures(const std::string configFile, TestContext const &context, std::vector<int> &expectedIterations)
 {
   using Eigen::Vector2d;
-  using namespace precice::constants;
 
   std::string meshName = context.isNamed("SolverOne") ? "MeshOne" : "MeshTwo";
 
-  precice::SolverInterface interface(context.name, configFile, 0, 1);
-  const int                meshID = interface.getMeshID(meshName);
+  precice::Participant interface(context.name, configFile, 0, 1);
 
   Vector2d vertex{0.0, 0.0};
 
   std::vector<double> writeValues = {1.0, 1.01, 2.0, 2.5, 2.8, 2.81};
 
-  VertexID vertexID = interface.setMeshVertex(meshID, vertex.data());
+  VertexID vertexID = interface.setMeshVertex(meshName, vertex);
 
   interface.initialize();
   int numberOfAdvanceCalls = 0;
@@ -27,23 +25,21 @@ void testConvergenceMeasures(const std::string configFile, TestContext const &co
   int timestep             = 0;
 
   while (interface.isCouplingOngoing()) {
-    if (interface.isActionRequired(actionWriteIterationCheckpoint())) {
+    if (interface.requiresWritingCheckpoint()) {
       numberOfIterations = 0;
-      interface.markActionFulfilled(actionWriteIterationCheckpoint());
     }
 
     if (context.isNamed("SolverTwo")) {
-      precice::DataID dataID = interface.getDataID("Data2", meshID);
-      interface.writeScalarData(dataID, vertexID, writeValues.at(numberOfAdvanceCalls));
+      auto dataName = "Data2";
+      interface.writeData(meshName, dataName, {&vertexID, 1}, {&writeValues.at(numberOfAdvanceCalls), 1});
     }
 
     interface.advance(1.0);
     ++numberOfAdvanceCalls;
     ++numberOfIterations;
 
-    if (interface.isActionRequired(actionReadIterationCheckpoint())) {
-      interface.markActionFulfilled(actionReadIterationCheckpoint());
-    } else { //converged
+    if (interface.requiresReadingCheckpoint()) {
+    } else { // converged
       BOOST_TEST(numberOfIterations == expectedIterations.at(timestep));
       ++timestep;
     }
@@ -51,4 +47,4 @@ void testConvergenceMeasures(const std::string configFile, TestContext const &co
   interface.finalize();
 }
 
-#endif
\ No newline at end of file
+#endif
